==> process-infinispan-persistence-springboot-0.9.1-sources.jar: org/acme/deals/DealreviewsProcess.java <==
package org.acme.deals;

import org.jbpm.process.core.datatype.impl.type.ObjectDataType;
import org.jbpm.ruleflow.core.RuleFlowProcessFactory;
import org.drools.core.util.KieFunctions;

@org.springframework.stereotype.Component("dealreviews")
public class DealreviewsProcess extends org.kie.kogito.process.impl.AbstractProcess<org.acme.deals.DealreviewsModel> {

    @org.springframework.beans.factory.annotation.Autowired(required = false)
    java.util.List<org.kie.api.runtime.process.WorkItemHandler> handlers;

    org.kie.kogito.app.Application app;

    public DealreviewsProcess() {
    }

    @org.springframework.beans.factory.annotation.Autowired()
    public DealreviewsProcess(org.kie.kogito.app.Application app) {
        super(app.config().process());
        this.app = app;
    }

    public org.acme.deals.DealreviewsProcessInstance createInstance(org.acme.deals.DealreviewsModel value) {
        return new org.acme.deals.DealreviewsProcessInstance(this, value, this.createLegacyProcessRuntime());
    }

    public org.acme.deals.DealreviewsProcessInstance createInstance(java.lang.String businessKey, org.acme.deals.DealreviewsModel value) {
        return new org.acme.deals.DealreviewsProcessInstance(this, value, businessKey, this.createLegacyProcessRuntime());
    }

    public org.acme.deals.DealreviewsModel createModel() {
        return new org.acme.deals.DealreviewsModel();
    }

    public org.acme.deals.DealreviewsProcessInstance createInstance(org.kie.kogito.Model value) {
        return this.createInstance((org.acme.deals.DealreviewsModel) value);
    }

    public org.acme.deals.DealreviewsProcessInstance createInstance(java.lang.String businessKey, org.kie.kogito.Model value) {
        return this.createInstance(businessKey, (org.acme.deals.DealreviewsModel) value);
    }

    public DealreviewsProcess configure() {
        super.configure();
        return this;
    }

    protected void registerListeners() {
    }

    public org.kie.api.definition.process.Process legacyProcess() {
        RuleFlowProcessFactory factory = RuleFlowProcessFactory.createProcess("dealreviews");
        factory.variable("deal", new ObjectDataType("java.lang.String"), "customTags", null);
        factory.variable("review", new ObjectDataType("java.lang.String"), "customTags", null);
        factory.variable("traveller", new ObjectDataType("org.acme.travels.Traveller"), "customTags", null);
        factory.name("Deal Review");
        factory.packageName("org.acme.deals");
        factory.dynamic(false);
        factory.version("1.0");
        factory.visibility("Public");
        factory.metaData("TargetNamespace", "http://www.omg.org/bpmn20");
        factory.imports("org.acme.travels.Traveller");
        org.jbpm.ruleflow.core.factory.EndNodeFactory endNode1 = factory.endNode(1);
        endNode1.name("End Event 1");
        endNode1.terminate(false);
        endNode1.metaData("UniqueId", "_AF59D427-38A9-4D28-B283-5916E2DABB2F");
        endNode1.metaData("elementname", "End Event 1");
        endNode1.metaData("x", 757);
        endNode1.metaData("width", 56);
        endNode1.metaData("y", 315);
        endNode1.metaData("height", 56);
        endNode1.done();
        org.jbpm.ruleflow.core.factory.HumanTaskNodeFactory humanTaskNode2 = factory.humanTaskNode(2);
        humanTaskNode2.name("Review the deal");
        humanTaskNode2.workParameter("TaskName", "review");
        humanTaskNode2.workParameter("Skippable", "true");
        humanTaskNode2.workParameter("ActorId", "john");
        humanTaskNode2.workParameter("NodeName", "Review the deal");
        humanTaskNode2.inMapping("deal", "deal");
        humanTaskNode2.inMapping("traveller", "traveller");
        humanTaskNode2.outMapping("review", "review");
        humanTaskNode2.done();
        humanTaskNode2.metaData("UniqueId", "_3597E33A-1C00-41B3-924E-09EA47F79D93");
        humanTaskNode2.metaData("elementname", "Review the deal");
        humanTaskNode2.metaData("x", 523);
        humanTaskNode2.metaData("width", 154);
        humanTaskNode2.metaData("y", 292);
        humanTaskNode2.metaData("height", 102);
        org.jbpm.ruleflow.core.factory.StartNodeFactory startNode3 = factory.startNode(3);
        startNode3.name("Start Process");
        startNode3.interrupting(true);
        startNode3.metaData("UniqueId", "_7E3D27D0-6644-4E55-8E41-9F68BD0D1327");
        startNode3.metaData("elementname", "Start Process");
        startNode3.metaData("x", 387);
        startNode3.metaData("width", 56);
        startNode3.metaData("y", 315);
        startNode3.metaData("height", 56);
        startNode3.done();
        factory.connection(2, 1, "_EECDD765-E29C-4D34-B390-25A729F40206");
        factory.connection(3, 2, "_0EF9197C-8AD7-422D-BE5F-E01CF996E44F");
        factory.validate();
        return factory.getProcess();
    }

    @org.springframework.beans.factory.annotation.Autowired()
    public void setProcessInstancesFactory(org.kie.kogito.process.ProcessInstancesFactory processInstancesFactory) {
        super.setProcessInstancesFactory(processInstancesFactory);
    }

    @javax.annotation.PostConstruct()
    public void init() {
        this.activate();
    }
}

==> process-infinispan-persistence-springboot-0.10.0-sources.jar: org/acme/deals/DealreviewsProcess.java <==
package org.acme.deals;

import org.jbpm.process.core.datatype.impl.type.ObjectDataType;
import org.jbpm.ruleflow.core.RuleFlowProcessFactory;
import org.drools.core.util.KieFunctions;

@org.springframework.stereotype.Component("dealreviews")
public class DealreviewsProcess extends org.kie.kogito.process.impl.AbstractProcess<org.acme.deals.DealreviewsModel> {

    @org.springframework.beans.factory.annotation.Autowired(required = false)
    java.util.Collection<org.kie.api.runtime.process.WorkItemHandler> handlers;

    org.kie.kogito.app.Application app;

    public DealreviewsProcess() {
    }

    @org.springframework.beans.factory.annotation.Autowired()
    public DealreviewsProcess(org.kie.kogito.app.Application app) {
        super(app.config().process());
        this.app = app;
    }

    public org.acme.deals.DealreviewsProcessInstance createInstance(org.acme.deals.DealreviewsModel value) {
        return new org.acme.deals.DealreviewsProcessInstance(this, value, this.createLegacyProcessRuntime());
    }

    public org.acme.deals.DealreviewsProcessInstance createInstance(java.lang.String businessKey, org.acme.deals.DealreviewsModel value) {
        return new org.acme.deals.DealreviewsProcessInstance(this, value, businessKey, this.createLegacyProcessRuntime());
    }

    public org.acme.deals.DealreviewsModel createModel() {
        return new org.acme.deals.DealreviewsModel();
    }

    public org.acme.deals.DealreviewsProcessInstance createInstance(org.kie.kogito.Model value) {
        return this.createInstance((org.acme.deals.DealreviewsModel) value);
    }

    public org.acme.deals.DealreviewsProcessInstance createInstance(java.lang.String businessKey, org.kie.kogito.Model value) {
        return this.createInstance(businessKey, (org.acme.deals.DealreviewsModel) value);
    }

    public DealreviewsProcess configure() {
        super.configure();
        return this;
    }

    protected void registerListeners() {
    }

    public org.kie.api.definition.process.Process legacyProcess() {
        RuleFlowProcessFactory factory = RuleFlowProcessFactory.createProcess("dealreviews");
        factory.variable("deal", new ObjectDataType("java.lang.String"), "customTags", null);
        factory.variable("review", new ObjectDataType("java.lang.String"), "customTags", null);
        factory.variable("traveller", new ObjectDataType("org.acme.travels.Traveller"), "customTags", null);
        factory.name("Deal Review");
        factory.packageName("org.acme.deals");
        factory.dynamic(false);
        factory.version("1.0");
        factory.visibility("Public");
        factory.metaData("TargetNamespace", "http://www.omg.org/bpmn20");
        factory.imports("org.acme.travels.Traveller");
        org.jbpm.ruleflow.core.factory.EndNodeFactory endNode1 = factory.endNode(1);
        endNode1.name("End Event 1");
        endNode1.terminate(false);
        endNode1.metaData("UniqueId", "_AF59D427-38A9-4D28-B283-5916E2DABB2F");
        endNode1.metaData("elementname", "End Event 1");
        endNode1.metaData("x", 757);
        endNode1.metaData("width", 56);
        endNode1.metaData("y", 315);
        endNode1.metaData("height", 56);
        endNode1.done();
        org.jbpm.ruleflow.core.factory.HumanTaskNodeFactory humanTaskNode2 = factory.humanTaskNode(2);
        humanTaskNode2.name("Review the deal");
        humanTaskNode2.workParameter("TaskName", "review");
        humanTaskNode2.workParameter("Skippable", "true");
        humanTaskNode2.workParameter("ActorId", "john");
        humanTaskNode2.workParameter("NodeName", "Review the deal");
        humanTaskNode2.inMapping("deal", "deal");
        humanTaskNode2.inMapping("traveller", "traveller");
        humanTaskNode2.outMapping("review", "review");
        humanTaskNode2.done();
        humanTaskNode2.metaData("UniqueId", "_3597E33A-1C00-41B3-924E-09EA47F79D93");
        humanTaskNode2.metaData("elementname", "Review the deal");
        humanTaskNode2.metaData("x", 523);
        humanTaskNode2.metaData("width", 154);
        humanTaskNode2.metaData("y", 292);
        humanTaskNode2.metaData("height", 102);
        org.jbpm.ruleflow.core.factory.StartNodeFactory startNode3 = factory.startNode(3);
        startNode3.name("Start Process");
        startNode3.interrupting(true);
        startNode3.metaData("UniqueId", "_7E3D27D0-6644-4E55-8E41-9F68BD0D1327");
        startNode3.metaData("elementname", "Start Process");
        startNode3.metaData("x", 387);
        startNode3.metaData("width", 56);
        startNode3.metaData("y", 315);
        startNode3.metaData("height", 56);
        startNode3.done();
        factory.connection(2, 1, "_EECDD765-E29C-4D34-B390-25A729F40206");
        factory.connection(3, 2, "_0EF9197C-8AD7-422D-BE5F-E01CF996E44F");
        factory.validate();
        return factory.getProcess();
    }

    @org.springframework.beans.factory.annotation.Autowired()
    public void setProcessInstancesFactory(org.kie.kogito.process.ProcessInstancesFactory processInstancesFactory) {
        super.setProcessInstancesFactory(processInstancesFactory);
    }

    @javax.annotation.PostConstruct()
    public void init() {
        this.activate();
    }
}
